<!--
SPDX-FileCopyrightText: 2020 IntelMQ Team

SPDX-License-Identifier: AGPL-3.0-or-later
-->

IntelMQ Manager Security Notes
==============================

Running IntelMQ Manager securely
--------------------------------

Please read the installation documentation at [`docs/INSTALL.md`, section "Security considerations"](docs/INSTALL.md#security-considerations).

Found a security issue?
-----------------------

In case you find security-relevant bugs in IntelMQ, please contact team@cert.at.
More information including the PGP key can be found on [CERT.at's website](https://www.cert.at/about/contact/contact_en.html).

